@@ -18,12 +18,10 @@ class SentView(TemplateView):
 
 
 class BaseContactView(FormView):
-
-    def __init__(self, success_url=None, body_template=None, subject_template=None, recipient_list=None):
-        self.success_url = success_url
-        self.body_template = body_template
-        self.subject_template = subject_template
-        self.recipient_list = recipient_list
+    success_url = None
+    body_template = None
+    subject_template = None
+    recipient_list = None
 
     def get_success_url(self):
         if self.success_url:
